You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@xerces.apache.org by mr...@apache.org on 2010/01/25 19:16:49 UTC

svn commit: r902904 - /xerces/java/trunk/tools/src/XJavac.java

Author: mrglavas
Date: Mon Jan 25 18:16:48 2010
New Revision: 902904

URL: http://svn.apache.org/viewvc?rev=902904&view=rev
Log:
Fixing JIRA Bug #1413: http://issues.apache.org/jira/browse/XERCESJ-1413. Allow Xerces to be built with the FreeBSD JDK.

Modified:
    xerces/java/trunk/tools/src/XJavac.java

Modified: xerces/java/trunk/tools/src/XJavac.java
URL: http://svn.apache.org/viewvc/xerces/java/trunk/tools/src/XJavac.java?rev=902904&r1=902903&r2=902904&view=diff
==============================================================================
--- xerces/java/trunk/tools/src/XJavac.java (original)
+++ xerces/java/trunk/tools/src/XJavac.java Mon Jan 25 18:16:48 2010
@@ -62,13 +62,14 @@
                 setBootclasspath(createIBMJDKBootclasspath());
             }
             // need to do special things for Sun too and also
             // for Apple, HP, SableVM, Kaffe and Blackdown: a Linux port of Sun Java
             else if( (vendor.indexOf("SUN") >= 0) || 
                      (vendor.indexOf("BLACKDOWN") >= 0) || 
                      (vendor.indexOf("APPLE") >= 0) ||
                      (vendor.indexOf("HEWLETT-PACKARD") >= 0) ||
                      (vendor.indexOf("KAFFE") >= 0) ||
-                     (vendor.indexOf("SABLE") >= 0)) {
+                     (vendor.indexOf("SABLE") >= 0) ||
+                     (vendor.indexOf("FREEBSD") >= 0)) {
                 // we're on an SUN 1.4 or higher; fiddle with the bootclasspath.
                 // since we can't eviscerate XML-related info here,
                 // we must use the classpath



---------------------------------------------------------------------
@@ -62,13 +62,14 @@
             }
             // need to do special things for Sun too and also
-            // for Apple, HP, SableVM, Kaffe and Blackdown: a Linux port of Sun Java
+            // for Apple, HP, FreeBSD, SableVM, Kaffe and Blackdown: a Linux port of Sun Java
             else if( (vendor.indexOf("SUN") >= 0) || 
                      (vendor.indexOf("BLACKDOWN") >= 0) || 
To unsubscribe, e-mail: commits-unsubscribe@xerces.apache.org
For additional commands, e-mail: commits-help@xerces.apache.org